@@ -1,11 +1,11 @@
 #
-# $Id: Api.pm,v cc27ffa878bb 2024/08/15 09:32:51 gomor $
+# $Id: Api.pm,v 462dcd9243b5 2024/10/31 09:09:10 gomor $
 #
 package Onyphe::Api;
 use strict;
 use warnings;
 
-our $VERSION = '4.15';
+our $VERSION = '4.16';
 
 use experimental qw(signatures);
 
@@ -703,6 +703,7 @@ sub ondemand ($self, $method, $api, $param, $post, $cb = undef, $cb_args = undef
    if (defined($param)) {
       $post->{maxscantime} = $param->{maxscantime} if defined $param->{maxscantime};
       $post->{aslines} = $param->{aslines} ? 'true' : 'false' if defined $param->{aslines};
+      $post->{aslink} = $param->{aslink} ? 'true' : 'false' if defined $param->{aslink};
       $post->{full} = $param->{full} ? 'true' : 'false' if defined $param->{full};
       $post->{urlscan} = $param->{urlscan} ? 'true' : 'false' if defined $param->{urlscan};
       $post->{vulnscan} = $param->{vulnscan} ? 'true' : 'false' if defined $param->{vulnscan};
@@ -847,6 +848,24 @@ sub ondemand_resolver_domain ($self, $target, $param = undef, $cb = undef, $cb_a
    return $self->ondemand('post', '/ondemand/resolver/domain/single', $param, { domain => $target }, $cb, $cb_args);
 }
 
+sub ondemand_resolver_domain_bulk ($self, $file, $param = undef, $cb = undef, $cb_args = undef) {
+   if (! -f $file) {
+      print STDERR "ERROR: Ondemand Resolver Domain Bulk needs a file as input\n"
+         unless $self->silent;
+   }
+
+   my @lines = read_file($file);
+   for (@lines) { chomp };
+   unless (@lines) {
+      print STDERR "ERROR: Ondemand Resolver Domain Bulk needs a file with content\n"
+         unless $self->silent;
+   }
+
+   my $target = join(',', @lines);
+
+   return $self->ondemand('post', '/ondemand/resolver/domain/bulk', $param, { domain => $target }, $cb, $cb_args);
+}
+
 sub ondemand_resolver_hostname ($self, $target, $param = undef, $cb = undef, $cb_args = undef) {
    return $self->ondemand('post', '/ondemand/resolver/hostname/single', $param, { hostname => $target }, $cb, $cb_args);
 }
@@ -951,6 +970,10 @@ sub asd_ns ($self, $target, $param = undef, $cb = undef, $cb_args = undef) {
    return $self->asd('post', '/asd/ns', $param, { domain => $target }, $cb, $cb_args);
 }
 
+sub asd_mx ($self, $target, $param = undef, $cb = undef, $cb_args = undef) {
+   return $self->asd('post', '/asd/mx', $param, { domain => $target }, $cb, $cb_args);
+}
+
 sub asd_task ($self, $taskid, $param = undef, $cb = undef, $cb_args = undef) {
    return $self->asd('get', '/asd/task/'.$taskid, $param, undef, $cb, $cb_args);
 }
